#
# spec file for package re2c
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           re2c
Version:        0.13.6
Release:        9.4
Summary:        Tool for generating C-based recognizers from regular expressions
License:        SUSE-Public-Domain
Group:          Development/Libraries/C and C++
Url:            http://re2c.org/
Source:         %{name}-%{version}.tar.gz
BuildRequires:  gcc-c++
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
re2c is a tool for writing fast and flexible lexers. Unlike other such
tools, it concentrates solely on generating efficient code for matching
regular expressions. This makes it suitable for a wide variety of
applications. The generated scanners approach hand-crafted ones in
terms of size and speed.

%prep
%setup -q
find lessons examples -type f -print0 \
    | xargs -r0 chmod -v a-x

%build
%configure
make %{?_smp_mflags} re2c
#regenerate file scanner.cc
rm -f scanner.cc
./re2c -g scanner.re > scanner.cc
rm -f re2c scanner.o
make %{?_smp_mflags}

%check
make test %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

%files
%defattr(-,root,root,-)
%{_bindir}/re2c
%{_mandir}/man1/re2c.1*
%doc doc/*.ps doc/sample.bib
%doc README CHANGELOG
%doc lessons/ examples/

%changelog
* Mon May 12 2014 tchvatal@suse.com
- Cleanup with spec-cleaner
- Sort out the %%prep finds that are no longer needed.
* Sat Aug  3 2013 crrodriguez@opensuse.org
- version 0.13.6
  * allow Yacc-style %%{code brackets}%%
  * allow C++ // comments
  * Fixed inplace configuration in -e mode
  * Fixed Wrong start_label in -c mode.
  * Fixed Unescaped backslash in file name of #line directive
* Fri Sep  9 2011 andrea.turrini@gmail.com
- Fixed typo in re2c.spec
* Tue Nov 23 2010 cristian.rodriguez@opensuse.org
-  Use smp_flags
- when rebuilding the scanner use -g, to generate GCC specific
  code that is slightly faster.
* Thu Jun 26 2008 mmarek@suse.cz
- updated to version 0.13.5
  * Fixed sf#1952896 Segfault in re2c::Scanner::scan.
  * Fixed sf#1952842 Regression.
* Mon Apr  7 2008 mmarek@suse.cz
- updated to version 0.13.4
  * Added transparent handling of #line directives in input files.
  * Added re2c:yyfill:check inplace configuration.
  * Added re2c:define:YYSETSTATE:naked inplace configuration.
  * Added re2c:flags:w and re2c:flags:u inplace configurations.
  * Added the ability to add rules in 'use:re2c' blocks.
  * Changed -r flag to accept only 'rules:re2c' and 'use:re2c'
    blocks.
* Mon Mar 17 2008 crrodriguez@suse.de
- update to version 0.13.3 , required for new PHP language parser
  * Added -r flag to allow reuse of scanner definitions.
  * Added -F flag to support flex syntax in rules.
  * Fixed SEGV in scanner that occurs with very large blocks.
  * Fixed issue with unused yybm.
  * Partial support for flex syntax.
  * Changed to allow /* comments with -c switch.
  * Added flag -D/--emit-dot.
* Mon Feb  4 2008 mmarek@suse.cz
- updated to version 0.13.1
  * build fixes for non-linux platforms only
* Mon Jun 25 2007 dmueller@suse.de
- add gcc-c++ buildrequires
* Mon Jun 25 2007 dmueller@suse.de
- update to versoin 0.13.0:
  * Fixed issue with short form of switches and parameter if not first switch.
  * Fixed #1708378 segfault in actions.cc.
  * Added -c and -t to generate scanners with (f)lex-like condition support.
* Thu May  3 2007 dmueller@suse.de
- update to version 0.12.0
* Sun Apr  1 2007 mrueckert@suse.de
- update to version 0.11.3
* Sun Mar  4 2007 mrueckert@suse.de
- update to version 0.11.2
* Tue Feb 20 2007 mrueckert@suse.de
- This version fixes a warning in the generated code that some
  compilers issue. No other changes have been made.
